"""Contains all the data models used in inputs/outputs"""

from .activity_create_dto import ActivityCreateDto
from .activity_response_dto import ActivityResponseDto
from .activity_statistics_response_dto import ActivityStatisticsResponseDto
from .add_users_dto import AddUsersDto
from .admin_onboarding_update_dto import AdminOnboardingUpdateDto
from .album_response_dto import AlbumResponseDto
from .album_statistics_response_dto import AlbumStatisticsResponseDto
from .album_user_add_dto import AlbumUserAddDto
from .album_user_create_dto import AlbumUserCreateDto
from .album_user_response_dto import AlbumUserResponseDto
from .album_user_role import AlbumUserRole
from .albums_add_assets_dto import AlbumsAddAssetsDto
from .albums_add_assets_response_dto import AlbumsAddAssetsResponseDto
from .albums_response import AlbumsResponse
from .albums_update import AlbumsUpdate
from .all_job_status_response_dto import AllJobStatusResponseDto
from .api_key_create_dto import APIKeyCreateDto
from .api_key_create_response_dto import APIKeyCreateResponseDto
from .api_key_response_dto import APIKeyResponseDto
from .api_key_update_dto import APIKeyUpdateDto
from .asset_bulk_delete_dto import AssetBulkDeleteDto
from .asset_bulk_update_dto import AssetBulkUpdateDto
from .asset_bulk_upload_check_dto import AssetBulkUploadCheckDto
from .asset_bulk_upload_check_item import AssetBulkUploadCheckItem
from .asset_bulk_upload_check_response_dto import AssetBulkUploadCheckResponseDto
from .asset_bulk_upload_check_result import AssetBulkUploadCheckResult
from .asset_bulk_upload_check_result_action import AssetBulkUploadCheckResultAction
from .asset_bulk_upload_check_result_reason import AssetBulkUploadCheckResultReason
from .asset_delta_sync_dto import AssetDeltaSyncDto
from .asset_delta_sync_response_dto import AssetDeltaSyncResponseDto
from .asset_face_create_dto import AssetFaceCreateDto
from .asset_face_delete_dto import AssetFaceDeleteDto
from .asset_face_response_dto import AssetFaceResponseDto
from .asset_face_update_dto import AssetFaceUpdateDto
from .asset_face_update_item import AssetFaceUpdateItem
from .asset_face_without_person_response_dto import AssetFaceWithoutPersonResponseDto
from .asset_full_sync_dto import AssetFullSyncDto
from .asset_ids_dto import AssetIdsDto
from .asset_ids_response_dto import AssetIdsResponseDto
from .asset_ids_response_dto_error import AssetIdsResponseDtoError
from .asset_job_name import AssetJobName
from .asset_jobs_dto import AssetJobsDto
from .asset_media_create_dto import AssetMediaCreateDto
from .asset_media_replace_dto import AssetMediaReplaceDto
from .asset_media_response_dto import AssetMediaResponseDto
from .asset_media_size import AssetMediaSize
from .asset_media_status import AssetMediaStatus
from .asset_metadata_key import AssetMetadataKey
from .asset_metadata_response_dto import AssetMetadataResponseDto
from .asset_metadata_response_dto_value import AssetMetadataResponseDtoValue
from .asset_metadata_upsert_dto import AssetMetadataUpsertDto
from .asset_metadata_upsert_item_dto import AssetMetadataUpsertItemDto
from .asset_metadata_upsert_item_dto_value import AssetMetadataUpsertItemDtoValue
from .asset_order import AssetOrder
from .asset_response_dto import AssetResponseDto
from .asset_stack_response_dto import AssetStackResponseDto
from .asset_stats_response_dto import AssetStatsResponseDto
from .asset_type_enum import AssetTypeEnum
from .asset_visibility import AssetVisibility
from .audio_codec import AudioCodec
from .auth_status_response_dto import AuthStatusResponseDto
from .avatar_update import AvatarUpdate
from .bulk_id_error_reason import BulkIdErrorReason
from .bulk_id_response_dto import BulkIdResponseDto
from .bulk_id_response_dto_error import BulkIdResponseDtoError
from .bulk_ids_dto import BulkIdsDto
from .cast_response import CastResponse
from .cast_update import CastUpdate
from .change_password_dto import ChangePasswordDto
from .check_existing_assets_dto import CheckExistingAssetsDto
from .check_existing_assets_response_dto import CheckExistingAssetsResponseDto
from .clip_config import CLIPConfig
from .colorspace import Colorspace
from .cq_mode import CQMode
from .create_album_dto import CreateAlbumDto
from .create_library_dto import CreateLibraryDto
from .create_profile_image_dto import CreateProfileImageDto
from .create_profile_image_response_dto import CreateProfileImageResponseDto
from .database_backup_config import DatabaseBackupConfig
from .download_archive_info import DownloadArchiveInfo
from .download_info_dto import DownloadInfoDto
from .download_response import DownloadResponse
from .download_response_dto import DownloadResponseDto
from .download_update import DownloadUpdate
from .duplicate_detection_config import DuplicateDetectionConfig
from .duplicate_response_dto import DuplicateResponseDto
from .email_notifications_response import EmailNotificationsResponse
from .email_notifications_update import EmailNotificationsUpdate
from .exif_response_dto import ExifResponseDto
from .face_dto import FaceDto
from .facial_recognition_config import FacialRecognitionConfig
from .folders_response import FoldersResponse
from .folders_update import FoldersUpdate
from .image_format import ImageFormat
from .job_command import JobCommand
from .job_command_dto import JobCommandDto
from .job_counts_dto import JobCountsDto
from .job_create_dto import JobCreateDto
from .job_name import JobName
from .job_settings_dto import JobSettingsDto
from .job_status_dto import JobStatusDto
from .library_response_dto import LibraryResponseDto
from .library_stats_response_dto import LibraryStatsResponseDto
from .license_key_dto import LicenseKeyDto
from .license_response_dto import LicenseResponseDto
from .log_level import LogLevel
from .login_credential_dto import LoginCredentialDto
from .login_response_dto import LoginResponseDto
from .logout_response_dto import LogoutResponseDto
from .machine_learning_availability_checks_dto import (
    MachineLearningAvailabilityChecksDto,
)
from .manual_job_name import ManualJobName
from .map_marker_response_dto import MapMarkerResponseDto
from .map_reverse_geocode_response_dto import MapReverseGeocodeResponseDto
from .memories_response import MemoriesResponse
from .memories_update import MemoriesUpdate
from .memory_create_dto import MemoryCreateDto
from .memory_response_dto import MemoryResponseDto
from .memory_statistics_response_dto import MemoryStatisticsResponseDto
from .memory_type import MemoryType
from .memory_update_dto import MemoryUpdateDto
from .merge_person_dto import MergePersonDto
from .metadata_search_dto import MetadataSearchDto
from .notification_create_dto import NotificationCreateDto
from .notification_create_dto_data import NotificationCreateDtoData
from .notification_delete_all_dto import NotificationDeleteAllDto
from .notification_dto import NotificationDto
from .notification_dto_data import NotificationDtoData
from .notification_level import NotificationLevel
from .notification_type import NotificationType
from .notification_update_all_dto import NotificationUpdateAllDto
from .notification_update_dto import NotificationUpdateDto
from .o_auth_authorize_response_dto import OAuthAuthorizeResponseDto
from .o_auth_callback_dto import OAuthCallbackDto
from .o_auth_config_dto import OAuthConfigDto
from .o_auth_token_endpoint_auth_method import OAuthTokenEndpointAuthMethod
from .on_this_day_dto import OnThisDayDto
from .onboarding_dto import OnboardingDto
from .onboarding_response_dto import OnboardingResponseDto
from .partner_create_dto import PartnerCreateDto
from .partner_direction import PartnerDirection
from .partner_response_dto import PartnerResponseDto
from .partner_update_dto import PartnerUpdateDto
from .people_response import PeopleResponse
from .people_response_dto import PeopleResponseDto
from .people_update import PeopleUpdate
from .people_update_dto import PeopleUpdateDto
from .people_update_item import PeopleUpdateItem
from .permission import Permission
from .person_create_dto import PersonCreateDto
from .person_response_dto import PersonResponseDto
from .person_statistics_response_dto import PersonStatisticsResponseDto
from .person_update_dto import PersonUpdateDto
from .person_with_faces_response_dto import PersonWithFacesResponseDto
from .pin_code_change_dto import PinCodeChangeDto
from .pin_code_reset_dto import PinCodeResetDto
from .pin_code_setup_dto import PinCodeSetupDto
from .places_response_dto import PlacesResponseDto
from .purchase_response import PurchaseResponse
from .purchase_update import PurchaseUpdate
from .queue_status_dto import QueueStatusDto
from .random_search_dto import RandomSearchDto
from .ratings_response import RatingsResponse
from .ratings_update import RatingsUpdate
from .reaction_level import ReactionLevel
from .reaction_type import ReactionType
from .reverse_geocoding_state_response_dto import ReverseGeocodingStateResponseDto
from .search_album_response_dto import SearchAlbumResponseDto
from .search_asset_response_dto import SearchAssetResponseDto
from .search_explore_item import SearchExploreItem
from .search_explore_response_dto import SearchExploreResponseDto
from .search_facet_count_response_dto import SearchFacetCountResponseDto
from .search_facet_response_dto import SearchFacetResponseDto
from .search_response_dto import SearchResponseDto
from .search_statistics_response_dto import SearchStatisticsResponseDto
from .search_suggestion_type import SearchSuggestionType
from .server_about_response_dto import ServerAboutResponseDto
from .server_apk_links_dto import ServerApkLinksDto
from .server_config_dto import ServerConfigDto
from .server_features_dto import ServerFeaturesDto
from .server_media_types_response_dto import ServerMediaTypesResponseDto
from .server_ping_response import ServerPingResponse
from .server_stats_response_dto import ServerStatsResponseDto
from .server_storage_response_dto import ServerStorageResponseDto
from .server_theme_dto import ServerThemeDto
from .server_version_history_response_dto import ServerVersionHistoryResponseDto
from .server_version_response_dto import ServerVersionResponseDto
from .session_create_dto import SessionCreateDto
from .session_create_response_dto import SessionCreateResponseDto
from .session_response_dto import SessionResponseDto
from .session_unlock_dto import SessionUnlockDto
from .session_update_dto import SessionUpdateDto
from .shared_link_create_dto import SharedLinkCreateDto
from .shared_link_edit_dto import SharedLinkEditDto
from .shared_link_response_dto import SharedLinkResponseDto
from .shared_link_type import SharedLinkType
from .shared_links_response import SharedLinksResponse
from .shared_links_update import SharedLinksUpdate
from .sign_up_dto import SignUpDto
from .smart_search_dto import SmartSearchDto
from .source_type import SourceType
from .stack_create_dto import StackCreateDto
from .stack_response_dto import StackResponseDto
from .stack_update_dto import StackUpdateDto
from .statistics_search_dto import StatisticsSearchDto
from .sync_ack_delete_dto import SyncAckDeleteDto
from .sync_ack_dto import SyncAckDto
from .sync_ack_set_dto import SyncAckSetDto
from .sync_ack_v1 import SyncAckV1
from .sync_album_delete_v1 import SyncAlbumDeleteV1
from .sync_album_to_asset_delete_v1 import SyncAlbumToAssetDeleteV1
from .sync_album_to_asset_v1 import SyncAlbumToAssetV1
from .sync_album_user_delete_v1 import SyncAlbumUserDeleteV1
from .sync_album_user_v1 import SyncAlbumUserV1
from .sync_album_v1 import SyncAlbumV1
from .sync_asset_delete_v1 import SyncAssetDeleteV1
from .sync_asset_exif_v1 import SyncAssetExifV1
from .sync_asset_face_delete_v1 import SyncAssetFaceDeleteV1
from .sync_asset_face_v1 import SyncAssetFaceV1
from .sync_asset_metadata_delete_v1 import SyncAssetMetadataDeleteV1
from .sync_asset_metadata_v1 import SyncAssetMetadataV1
from .sync_asset_metadata_v1_value import SyncAssetMetadataV1Value
from .sync_asset_v1 import SyncAssetV1
from .sync_auth_user_v1 import SyncAuthUserV1
from .sync_complete_v1 import SyncCompleteV1
from .sync_entity_type import SyncEntityType
from .sync_memory_asset_delete_v1 import SyncMemoryAssetDeleteV1
from .sync_memory_asset_v1 import SyncMemoryAssetV1
from .sync_memory_delete_v1 import SyncMemoryDeleteV1
from .sync_memory_v1 import SyncMemoryV1
from .sync_memory_v1_data import SyncMemoryV1Data
from .sync_partner_delete_v1 import SyncPartnerDeleteV1
from .sync_partner_v1 import SyncPartnerV1
from .sync_person_delete_v1 import SyncPersonDeleteV1
from .sync_person_v1 import SyncPersonV1
from .sync_request_type import SyncRequestType
from .sync_reset_v1 import SyncResetV1
from .sync_stack_delete_v1 import SyncStackDeleteV1
from .sync_stack_v1 import SyncStackV1
from .sync_stream_dto import SyncStreamDto
from .sync_user_delete_v1 import SyncUserDeleteV1
from .sync_user_metadata_delete_v1 import SyncUserMetadataDeleteV1
from .sync_user_metadata_v1 import SyncUserMetadataV1
from .sync_user_metadata_v1_value import SyncUserMetadataV1Value
from .sync_user_v1 import SyncUserV1
from .system_config_backups_dto import SystemConfigBackupsDto
from .system_config_dto import SystemConfigDto
from .system_config_f_fmpeg_dto import SystemConfigFFmpegDto
from .system_config_faces_dto import SystemConfigFacesDto
from .system_config_generated_fullsize_image_dto import (
    SystemConfigGeneratedFullsizeImageDto,
)
from .system_config_generated_image_dto import SystemConfigGeneratedImageDto
from .system_config_image_dto import SystemConfigImageDto
from .system_config_job_dto import SystemConfigJobDto
from .system_config_library_dto import SystemConfigLibraryDto
from .system_config_library_scan_dto import SystemConfigLibraryScanDto
from .system_config_library_watch_dto import SystemConfigLibraryWatchDto
from .system_config_logging_dto import SystemConfigLoggingDto
from .system_config_machine_learning_dto import SystemConfigMachineLearningDto
from .system_config_map_dto import SystemConfigMapDto
from .system_config_metadata_dto import SystemConfigMetadataDto
from .system_config_new_version_check_dto import SystemConfigNewVersionCheckDto
from .system_config_nightly_tasks_dto import SystemConfigNightlyTasksDto
from .system_config_notifications_dto import SystemConfigNotificationsDto
from .system_config_o_auth_dto import SystemConfigOAuthDto
from .system_config_password_login_dto import SystemConfigPasswordLoginDto
from .system_config_reverse_geocoding_dto import SystemConfigReverseGeocodingDto
from .system_config_server_dto import SystemConfigServerDto
from .system_config_smtp_dto import SystemConfigSmtpDto
from .system_config_smtp_transport_dto import SystemConfigSmtpTransportDto
from .system_config_storage_template_dto import SystemConfigStorageTemplateDto
from .system_config_template_emails_dto import SystemConfigTemplateEmailsDto
from .system_config_template_storage_option_dto import (
    SystemConfigTemplateStorageOptionDto,
)
from .system_config_templates_dto import SystemConfigTemplatesDto
from .system_config_theme_dto import SystemConfigThemeDto
from .system_config_trash_dto import SystemConfigTrashDto
from .system_config_user_dto import SystemConfigUserDto
from .tag_bulk_assets_dto import TagBulkAssetsDto
from .tag_bulk_assets_response_dto import TagBulkAssetsResponseDto
from .tag_create_dto import TagCreateDto
from .tag_response_dto import TagResponseDto
from .tag_update_dto import TagUpdateDto
from .tag_upsert_dto import TagUpsertDto
from .tags_response import TagsResponse
from .tags_update import TagsUpdate
from .template_dto import TemplateDto
from .template_response_dto import TemplateResponseDto
from .test_email_response_dto import TestEmailResponseDto
from .time_bucket_asset_response_dto import TimeBucketAssetResponseDto
from .time_buckets_response_dto import TimeBucketsResponseDto
from .tone_mapping import ToneMapping
from .transcode_hw_accel import TranscodeHWAccel
from .transcode_policy import TranscodePolicy
from .trash_response_dto import TrashResponseDto
from .update_album_dto import UpdateAlbumDto
from .update_album_user_dto import UpdateAlbumUserDto
from .update_asset_dto import UpdateAssetDto
from .update_library_dto import UpdateLibraryDto
from .usage_by_user_dto import UsageByUserDto
from .user_admin_create_dto import UserAdminCreateDto
from .user_admin_delete_dto import UserAdminDeleteDto
from .user_admin_response_dto import UserAdminResponseDto
from .user_admin_update_dto import UserAdminUpdateDto
from .user_avatar_color import UserAvatarColor
from .user_license import UserLicense
from .user_metadata_key import UserMetadataKey
from .user_preferences_response_dto import UserPreferencesResponseDto
from .user_preferences_update_dto import UserPreferencesUpdateDto
from .user_response_dto import UserResponseDto
from .user_status import UserStatus
from .user_update_me_dto import UserUpdateMeDto
from .validate_access_token_response_dto import ValidateAccessTokenResponseDto
from .validate_library_dto import ValidateLibraryDto
from .validate_library_import_path_response_dto import (
    ValidateLibraryImportPathResponseDto,
)
from .validate_library_response_dto import ValidateLibraryResponseDto
from .version_check_state_response_dto import VersionCheckStateResponseDto
from .video_codec import VideoCodec
from .video_container import VideoContainer

__all__ = (
    "ActivityCreateDto",
    "ActivityResponseDto",
    "ActivityStatisticsResponseDto",
    "AddUsersDto",
    "AdminOnboardingUpdateDto",
    "AlbumResponseDto",
    "AlbumsAddAssetsDto",
    "AlbumsAddAssetsResponseDto",
    "AlbumsResponse",
    "AlbumStatisticsResponseDto",
    "AlbumsUpdate",
    "AlbumUserAddDto",
    "AlbumUserCreateDto",
    "AlbumUserResponseDto",
    "AlbumUserRole",
    "AllJobStatusResponseDto",
    "APIKeyCreateDto",
    "APIKeyCreateResponseDto",
    "APIKeyResponseDto",
    "APIKeyUpdateDto",
    "AssetBulkDeleteDto",
    "AssetBulkUpdateDto",
    "AssetBulkUploadCheckDto",
    "AssetBulkUploadCheckItem",
    "AssetBulkUploadCheckResponseDto",
    "AssetBulkUploadCheckResult",
    "AssetBulkUploadCheckResultAction",
    "AssetBulkUploadCheckResultReason",
    "AssetDeltaSyncDto",
    "AssetDeltaSyncResponseDto",
    "AssetFaceCreateDto",
    "AssetFaceDeleteDto",
    "AssetFaceResponseDto",
    "AssetFaceUpdateDto",
    "AssetFaceUpdateItem",
    "AssetFaceWithoutPersonResponseDto",
    "AssetFullSyncDto",
    "AssetIdsDto",
    "AssetIdsResponseDto",
    "AssetIdsResponseDtoError",
    "AssetJobName",
    "AssetJobsDto",
    "AssetMediaCreateDto",
    "AssetMediaReplaceDto",
    "AssetMediaResponseDto",
    "AssetMediaSize",
    "AssetMediaStatus",
    "AssetMetadataKey",
    "AssetMetadataResponseDto",
    "AssetMetadataResponseDtoValue",
    "AssetMetadataUpsertDto",
    "AssetMetadataUpsertItemDto",
    "AssetMetadataUpsertItemDtoValue",
    "AssetOrder",
    "AssetResponseDto",
    "AssetStackResponseDto",
    "AssetStatsResponseDto",
    "AssetTypeEnum",
    "AssetVisibility",
    "AudioCodec",
    "AuthStatusResponseDto",
    "AvatarUpdate",
    "BulkIdErrorReason",
    "BulkIdResponseDto",
    "BulkIdResponseDtoError",
    "BulkIdsDto",
    "CastResponse",
    "CastUpdate",
    "ChangePasswordDto",
    "CheckExistingAssetsDto",
    "CheckExistingAssetsResponseDto",
    "CLIPConfig",
    "Colorspace",
    "CQMode",
    "CreateAlbumDto",
    "CreateLibraryDto",
    "CreateProfileImageDto",
    "CreateProfileImageResponseDto",
    "DatabaseBackupConfig",
    "DownloadArchiveInfo",
    "DownloadInfoDto",
    "DownloadResponse",
    "DownloadResponseDto",
    "DownloadUpdate",
    "DuplicateDetectionConfig",
    "DuplicateResponseDto",
    "EmailNotificationsResponse",
    "EmailNotificationsUpdate",
    "ExifResponseDto",
    "FaceDto",
    "FacialRecognitionConfig",
    "FoldersResponse",
    "FoldersUpdate",
    "ImageFormat",
    "JobCommand",
    "JobCommandDto",
    "JobCountsDto",
    "JobCreateDto",
    "JobName",
    "JobSettingsDto",
    "JobStatusDto",
    "LibraryResponseDto",
    "LibraryStatsResponseDto",
    "LicenseKeyDto",
    "LicenseResponseDto",
    "LoginCredentialDto",
    "LoginResponseDto",
    "LogLevel",
    "LogoutResponseDto",
    "MachineLearningAvailabilityChecksDto",
    "ManualJobName",
    "MapMarkerResponseDto",
    "MapReverseGeocodeResponseDto",
    "MemoriesResponse",
    "MemoriesUpdate",
    "MemoryCreateDto",
    "MemoryResponseDto",
    "MemoryStatisticsResponseDto",
    "MemoryType",
    "MemoryUpdateDto",
    "MergePersonDto",
    "MetadataSearchDto",
    "NotificationCreateDto",
    "NotificationCreateDtoData",
    "NotificationDeleteAllDto",
    "NotificationDto",
    "NotificationDtoData",
    "NotificationLevel",
    "NotificationType",
    "NotificationUpdateAllDto",
    "NotificationUpdateDto",
    "OAuthAuthorizeResponseDto",
    "OAuthCallbackDto",
    "OAuthConfigDto",
    "OAuthTokenEndpointAuthMethod",
    "OnboardingDto",
    "OnboardingResponseDto",
    "OnThisDayDto",
    "PartnerCreateDto",
    "PartnerDirection",
    "PartnerResponseDto",
    "PartnerUpdateDto",
    "PeopleResponse",
    "PeopleResponseDto",
    "PeopleUpdate",
    "PeopleUpdateDto",
    "PeopleUpdateItem",
    "Permission",
    "PersonCreateDto",
    "PersonResponseDto",
    "PersonStatisticsResponseDto",
    "PersonUpdateDto",
    "PersonWithFacesResponseDto",
    "PinCodeChangeDto",
    "PinCodeResetDto",
    "PinCodeSetupDto",
    "PlacesResponseDto",
    "PurchaseResponse",
    "PurchaseUpdate",
    "QueueStatusDto",
    "RandomSearchDto",
    "RatingsResponse",
    "RatingsUpdate",
    "ReactionLevel",
    "ReactionType",
    "ReverseGeocodingStateResponseDto",
    "SearchAlbumResponseDto",
    "SearchAssetResponseDto",
    "SearchExploreItem",
    "SearchExploreResponseDto",
    "SearchFacetCountResponseDto",
    "SearchFacetResponseDto",
    "SearchResponseDto",
    "SearchStatisticsResponseDto",
    "SearchSuggestionType",
    "ServerAboutResponseDto",
    "ServerApkLinksDto",
    "ServerConfigDto",
    "ServerFeaturesDto",
    "ServerMediaTypesResponseDto",
    "ServerPingResponse",
    "ServerStatsResponseDto",
    "ServerStorageResponseDto",
    "ServerThemeDto",
    "ServerVersionHistoryResponseDto",
    "ServerVersionResponseDto",
    "SessionCreateDto",
    "SessionCreateResponseDto",
    "SessionResponseDto",
    "SessionUnlockDto",
    "SessionUpdateDto",
    "SharedLinkCreateDto",
    "SharedLinkEditDto",
    "SharedLinkResponseDto",
    "SharedLinksResponse",
    "SharedLinksUpdate",
    "SharedLinkType",
    "SignUpDto",
    "SmartSearchDto",
    "SourceType",
    "StackCreateDto",
    "StackResponseDto",
    "StackUpdateDto",
    "StatisticsSearchDto",
    "SyncAckDeleteDto",
    "SyncAckDto",
    "SyncAckSetDto",
    "SyncAckV1",
    "SyncAlbumDeleteV1",
    "SyncAlbumToAssetDeleteV1",
    "SyncAlbumToAssetV1",
    "SyncAlbumUserDeleteV1",
    "SyncAlbumUserV1",
    "SyncAlbumV1",
    "SyncAssetDeleteV1",
    "SyncAssetExifV1",
    "SyncAssetFaceDeleteV1",
    "SyncAssetFaceV1",
    "SyncAssetMetadataDeleteV1",
    "SyncAssetMetadataV1",
    "SyncAssetMetadataV1Value",
    "SyncAssetV1",
    "SyncAuthUserV1",
    "SyncCompleteV1",
    "SyncEntityType",
    "SyncMemoryAssetDeleteV1",
    "SyncMemoryAssetV1",
    "SyncMemoryDeleteV1",
    "SyncMemoryV1",
    "SyncMemoryV1Data",
    "SyncPartnerDeleteV1",
    "SyncPartnerV1",
    "SyncPersonDeleteV1",
    "SyncPersonV1",
    "SyncRequestType",
    "SyncResetV1",
    "SyncStackDeleteV1",
    "SyncStackV1",
    "SyncStreamDto",
    "SyncUserDeleteV1",
    "SyncUserMetadataDeleteV1",
    "SyncUserMetadataV1",
    "SyncUserMetadataV1Value",
    "SyncUserV1",
    "SystemConfigBackupsDto",
    "SystemConfigDto",
    "SystemConfigFacesDto",
    "SystemConfigFFmpegDto",
    "SystemConfigGeneratedFullsizeImageDto",
    "SystemConfigGeneratedImageDto",
    "SystemConfigImageDto",
    "SystemConfigJobDto",
    "SystemConfigLibraryDto",
    "SystemConfigLibraryScanDto",
    "SystemConfigLibraryWatchDto",
    "SystemConfigLoggingDto",
    "SystemConfigMachineLearningDto",
    "SystemConfigMapDto",
    "SystemConfigMetadataDto",
    "SystemConfigNewVersionCheckDto",
    "SystemConfigNightlyTasksDto",
    "SystemConfigNotificationsDto",
    "SystemConfigOAuthDto",
    "SystemConfigPasswordLoginDto",
    "SystemConfigReverseGeocodingDto",
    "SystemConfigServerDto",
    "SystemConfigSmtpDto",
    "SystemConfigSmtpTransportDto",
    "SystemConfigStorageTemplateDto",
    "SystemConfigTemplateEmailsDto",
    "SystemConfigTemplatesDto",
    "SystemConfigTemplateStorageOptionDto",
    "SystemConfigThemeDto",
    "SystemConfigTrashDto",
    "SystemConfigUserDto",
    "TagBulkAssetsDto",
    "TagBulkAssetsResponseDto",
    "TagCreateDto",
    "TagResponseDto",
    "TagsResponse",
    "TagsUpdate",
    "TagUpdateDto",
    "TagUpsertDto",
    "TemplateDto",
    "TemplateResponseDto",
    "TestEmailResponseDto",
    "TimeBucketAssetResponseDto",
    "TimeBucketsResponseDto",
    "ToneMapping",
    "TranscodeHWAccel",
    "TranscodePolicy",
    "TrashResponseDto",
    "UpdateAlbumDto",
    "UpdateAlbumUserDto",
    "UpdateAssetDto",
    "UpdateLibraryDto",
    "UsageByUserDto",
    "UserAdminCreateDto",
    "UserAdminDeleteDto",
    "UserAdminResponseDto",
    "UserAdminUpdateDto",
    "UserAvatarColor",
    "UserLicense",
    "UserMetadataKey",
    "UserPreferencesResponseDto",
    "UserPreferencesUpdateDto",
    "UserResponseDto",
    "UserStatus",
    "UserUpdateMeDto",
    "ValidateAccessTokenResponseDto",
    "ValidateLibraryDto",
    "ValidateLibraryImportPathResponseDto",
    "ValidateLibraryResponseDto",
    "VersionCheckStateResponseDto",
    "VideoCodec",
    "VideoContainer",
)



from collections.abc import Mapping
from typing import (
    TYPE_CHECKING,
    Any,
    TypeVar,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.colorspace import Colorspace

if TYPE_CHECKING:
    from ..models.system_config_generated_fullsize_image_dto import (
        SystemConfigGeneratedFullsizeImageDto,
    )
    from ..models.system_config_generated_image_dto import SystemConfigGeneratedImageDto


T = TypeVar("T", bound="SystemConfigImageDto")


@_attrs_define
class SystemConfigImageDto:
    """
    Attributes:
        colorspace (Colorspace):
        extract_embedded (bool):
        fullsize (SystemConfigGeneratedFullsizeImageDto):
        preview (SystemConfigGeneratedImageDto):
        thumbnail (SystemConfigGeneratedImageDto):
    """

    colorspace: Colorspace
    extract_embedded: bool
    fullsize: "SystemConfigGeneratedFullsizeImageDto"
    preview: "SystemConfigGeneratedImageDto"
    thumbnail: "SystemConfigGeneratedImageDto"
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        colorspace = self.colorspace.value

        extract_embedded = self.extract_embedded

        fullsize = self.fullsize.to_dict()

        preview = self.preview.to_dict()

        thumbnail = self.thumbnail.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "colorspace": colorspace,
                "extractEmbedded": extract_embedded,
                "fullsize": fullsize,
                "preview": preview,
                "thumbnail": thumbnail,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.system_config_generated_fullsize_image_dto import (
            SystemConfigGeneratedFullsizeImageDto,
        )
        from ..models.system_config_generated_image_dto import (
            SystemConfigGeneratedImageDto,
        )

        d = dict(src_dict)
        colorspace = Colorspace(d.pop("colorspace"))

        extract_embedded = d.pop("extractEmbedded")

        fullsize = SystemConfigGeneratedFullsizeImageDto.from_dict(d.pop("fullsize"))

        preview = SystemConfigGeneratedImageDto.from_dict(d.pop("preview"))

        thumbnail = SystemConfigGeneratedImageDto.from_dict(d.pop("thumbnail"))

        system_config_image_dto = cls(
            colorspace=colorspace,
            extract_embedded=extract_embedded,
            fullsize=fullsize,
            preview=preview,
            thumbnail=thumbnail,
        )

        system_config_image_dto.additional_properties = d
        return system_config_image_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="AssetFaceCreateDto")


@_attrs_define
class AssetFaceCreateDto:
    """
    Attributes:
        asset_id (UUID):
        height (int):
        image_height (int):
        image_width (int):
        person_id (UUID):
        width (int):
        x (int):
        y (int):
    """

    asset_id: UUID
    height: int
    image_height: int
    image_width: int
    person_id: UUID
    width: int
    x: int
    y: int
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        asset_id = str(self.asset_id)

        height = self.height

        image_height = self.image_height

        image_width = self.image_width

        person_id = str(self.person_id)

        width = self.width

        x = self.x

        y = self.y

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "assetId": asset_id,
                "height": height,
                "imageHeight": image_height,
                "imageWidth": image_width,
                "personId": person_id,
                "width": width,
                "x": x,
                "y": y,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        asset_id = UUID(d.pop("assetId"))

        height = d.pop("height")

        image_height = d.pop("imageHeight")

        image_width = d.pop("imageWidth")

        person_id = UUID(d.pop("personId"))

        width = d.pop("width")

        x = d.pop("x")

        y = d.pop("y")

        asset_face_create_dto = cls(
            asset_id=asset_id,
            height=height,
            image_height=image_height,
            image_width=image_width,
            person_id=person_id,
            width=width,
            x=x,
            y=y,
        )

        asset_face_create_dto.additional_properties = d
        return asset_face_create_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from collections.abc import Mapping
from typing import (
    TYPE_CHECKING,
    Any,
    TypeVar,
    Union,
)
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.memory_type import MemoryType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.on_this_day_dto import OnThisDayDto


T = TypeVar("T", bound="MemoryCreateDto")


@_attrs_define
class MemoryCreateDto:
    """
    Attributes:
        data (OnThisDayDto):
        memory_at (datetime.datetime):
        type_ (MemoryType):
        asset_ids (Union[Unset, list[UUID]]):
        is_saved (Union[Unset, bool]):
        seen_at (Union[Unset, datetime.datetime]):
    """

    data: "OnThisDayDto"
    memory_at: datetime.datetime
    type_: MemoryType
    asset_ids: Union[Unset, list[UUID]] = UNSET
    is_saved: Union[Unset, bool] = UNSET
    seen_at: Union[Unset, datetime.datetime] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        data = self.data.to_dict()

        memory_at = self.memory_at.isoformat()

        type_ = self.type_.value

        asset_ids: Union[Unset, list[str]] = UNSET
        if not isinstance(self.asset_ids, Unset):
            asset_ids = []
            for asset_ids_item_data in self.asset_ids:
                asset_ids_item = str(asset_ids_item_data)
                asset_ids.append(asset_ids_item)

        is_saved = self.is_saved

        seen_at: Union[Unset, str] = UNSET
        if not isinstance(self.seen_at, Unset):
            seen_at = self.seen_at.isoformat()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "data": data,
                "memoryAt": memory_at,
                "type": type_,
            }
        )
        if asset_ids is not UNSET:
            field_dict["assetIds"] = asset_ids
        if is_saved is not UNSET:
            field_dict["isSaved"] = is_saved
        if seen_at is not UNSET:
            field_dict["seenAt"] = seen_at

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.on_this_day_dto import OnThisDayDto

        d = dict(src_dict)
        data = OnThisDayDto.from_dict(d.pop("data"))

        memory_at = isoparse(d.pop("memoryAt"))

        type_ = MemoryType(d.pop("type"))

        asset_ids = []
        _asset_ids = d.pop("assetIds", UNSET)
        for asset_ids_item_data in _asset_ids or []:
            asset_ids_item = UUID(asset_ids_item_data)

            asset_ids.append(asset_ids_item)

        is_saved = d.pop("isSaved", UNSET)

        _seen_at = d.pop("seenAt", UNSET)
        seen_at: Union[Unset, datetime.datetime]
        if isinstance(_seen_at, Unset):
            seen_at = UNSET
        else:
            seen_at = isoparse(_seen_at)

        memory_create_dto = cls(
            data=data,
            memory_at=memory_at,
            type_=type_,
            asset_ids=asset_ids,
            is_saved=is_saved,
            seen_at=seen_at,
        )

        memory_create_dto.additional_properties = d
        return memory_create_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from collections.abc import Mapping
from typing import (
    Any,
    TypeVar,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

T = TypeVar("T", bound="CreateProfileImageResponseDto")


@_attrs_define
class CreateProfileImageResponseDto:
    """
    Attributes:
        profile_changed_at (datetime.datetime):
        profile_image_path (str):
        user_id (str):
    """

    profile_changed_at: datetime.datetime
    profile_image_path: str
    user_id: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        profile_changed_at = self.profile_changed_at.isoformat()

        profile_image_path = self.profile_image_path

        user_id = self.user_id

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "profileChangedAt": profile_changed_at,
                "profileImagePath": profile_image_path,
                "userId": user_id,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        profile_changed_at = isoparse(d.pop("profileChangedAt"))

        profile_image_path = d.pop("profileImagePath")

        user_id = d.pop("userId")

        create_profile_image_response_dto = cls(
            profile_changed_at=profile_changed_at,
            profile_image_path=profile_image_path,
            user_id=user_id,
        )

        create_profile_image_response_dto.additional_properties = d
        return create_profile_image_response_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from collections.abc import Mapping
from typing import (
    TYPE_CHECKING,
    Any,
    TypeVar,
    Union,
    cast,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.user_avatar_color import UserAvatarColor
from ..models.user_status import UserStatus

if TYPE_CHECKING:
    from ..models.user_license import UserLicense


T = TypeVar("T", bound="UserAdminResponseDto")


@_attrs_define
class UserAdminResponseDto:
    """
    Attributes:
        avatar_color (UserAvatarColor):
        created_at (datetime.datetime):
        deleted_at (Union[None, datetime.datetime]):
        email (str):
        id (str):
        is_admin (bool):
        license_ (Union['UserLicense', None]):
        name (str):
        oauth_id (str):
        profile_changed_at (datetime.datetime):
        profile_image_path (str):
        quota_size_in_bytes (Union[None, int]):
        quota_usage_in_bytes (Union[None, int]):
        should_change_password (bool):
        status (UserStatus):
        storage_label (Union[None, str]):
        updated_at (datetime.datetime):
    """

    avatar_color: UserAvatarColor
    created_at: datetime.datetime
    deleted_at: Union[None, datetime.datetime]
    email: str
    id: str
    is_admin: bool
    license_: Union["UserLicense", None]
    name: str
    oauth_id: str
    profile_changed_at: datetime.datetime
    profile_image_path: str
    quota_size_in_bytes: Union[None, int]
    quota_usage_in_bytes: Union[None, int]
    should_change_password: bool
    status: UserStatus
    storage_label: Union[None, str]
    updated_at: datetime.datetime
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.user_license import UserLicense

        avatar_color = self.avatar_color.value

        created_at = self.created_at.isoformat()

        deleted_at: Union[None, str]
        if isinstance(self.deleted_at, datetime.datetime):
            deleted_at = self.deleted_at.isoformat()
        else:
            deleted_at = self.deleted_at

        email = self.email

        id = self.id

        is_admin = self.is_admin

        license_: Union[None, dict[str, Any]]
        if isinstance(self.license_, UserLicense):
            license_ = self.license_.to_dict()
        else:
            license_ = self.license_

        name = self.name

        oauth_id = self.oauth_id

        profile_changed_at = self.profile_changed_at.isoformat()

        profile_image_path = self.profile_image_path

        quota_size_in_bytes: Union[None, int]
        quota_size_in_bytes = self.quota_size_in_bytes

        quota_usage_in_bytes: Union[None, int]
        quota_usage_in_bytes = self.quota_usage_in_bytes

        should_change_password = self.should_change_password

        status = self.status.value

        storage_label: Union[None, str]
        storage_label = self.storage_label

        updated_at = self.updated_at.isoformat()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "avatarColor": avatar_color,
                "createdAt": created_at,
                "deletedAt": deleted_at,
                "email": email,
                "id": id,
                "isAdmin": is_admin,
                "license": license_,
                "name": name,
                "oauthId": oauth_id,
                "profileChangedAt": profile_changed_at,
                "profileImagePath": profile_image_path,
                "quotaSizeInBytes": quota_size_in_bytes,
                "quotaUsageInBytes": quota_usage_in_bytes,
                "shouldChangePassword": should_change_password,
                "status": status,
                "storageLabel": storage_label,
                "updatedAt": updated_at,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.user_license import UserLicense

        d = dict(src_dict)
        avatar_color = UserAvatarColor(d.pop("avatarColor"))

        created_at = isoparse(d.pop("createdAt"))

        def _parse_deleted_at(data: object) -> Union[None, datetime.datetime]:
            if data is None:
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                deleted_at_type_0 = isoparse(data)

                return deleted_at_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, datetime.datetime], data)

        deleted_at = _parse_deleted_at(d.pop("deletedAt"))

        email = d.pop("email")

        id = d.pop("id")

        is_admin = d.pop("isAdmin")

        def _parse_license_(data: object) -> Union["UserLicense", None]:
            if data is None:
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                license_type_1 = UserLicense.from_dict(data)

                return license_type_1
            except:  # noqa: E722
                pass
            return cast(Union["UserLicense", None], data)

        license_ = _parse_license_(d.pop("license"))

        name = d.pop("name")

        oauth_id = d.pop("oauthId")

        profile_changed_at = isoparse(d.pop("profileChangedAt"))

        profile_image_path = d.pop("profileImagePath")

        def _parse_quota_size_in_bytes(data: object) -> Union[None, int]:
            if data is None:
                return data
            return cast(Union[None, int], data)

        quota_size_in_bytes = _parse_quota_size_in_bytes(d.pop("quotaSizeInBytes"))

        def _parse_quota_usage_in_bytes(data: object) -> Union[None, int]:
            if data is None:
                return data
            return cast(Union[None, int], data)

        quota_usage_in_bytes = _parse_quota_usage_in_bytes(d.pop("quotaUsageInBytes"))

        should_change_password = d.pop("shouldChangePassword")

        status = UserStatus(d.pop("status"))

        def _parse_storage_label(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        storage_label = _parse_storage_label(d.pop("storageLabel"))

        updated_at = isoparse(d.pop("updatedAt"))

        user_admin_response_dto = cls(
            avatar_color=avatar_color,
            created_at=created_at,
            deleted_at=deleted_at,
            email=email,
            id=id,
            is_admin=is_admin,
            license_=license_,
            name=name,
            oauth_id=oauth_id,
            profile_changed_at=profile_changed_at,
            profile_image_path=profile_image_path,
            quota_size_in_bytes=quota_size_in_bytes,
            quota_usage_in_bytes=quota_usage_in_bytes,
            should_change_password=should_change_password,
            status=status,
            storage_label=storage_label,
            updated_at=updated_at,
        )

        user_admin_response_dto.additional_properties = d
        return user_admin_response_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class TranscodeHWAccel(str, Enum):
    DISABLED = "disabled"
    NVENC = "nvenc"
    QSV = "qsv"
    RKMPP = "rkmpp"
    VAAPI = "vaapi"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import (
    Any,
    TypeVar,
    Union,
    cast,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.user_avatar_color import UserAvatarColor
from ..types import UNSET, Unset

T = TypeVar("T", bound="UserAdminCreateDto")


@_attrs_define
class UserAdminCreateDto:
    """
    Attributes:
        email (str):
        name (str):
        password (str):
        avatar_color (Union[None, Unset, UserAvatarColor]):
        is_admin (Union[Unset, bool]):
        notify (Union[Unset, bool]):
        quota_size_in_bytes (Union[None, Unset, int]):
        should_change_password (Union[Unset, bool]):
        storage_label (Union[None, Unset, str]):
    """

    email: str
    name: str
    password: str
    avatar_color: Union[None, Unset, UserAvatarColor] = UNSET
    is_admin: Union[Unset, bool] = UNSET
    notify: Union[Unset, bool] = UNSET
    quota_size_in_bytes: Union[None, Unset, int] = UNSET
    should_change_password: Union[Unset, bool] = UNSET
    storage_label: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        email = self.email

        name = self.name

        password = self.password

        avatar_color: Union[None, Unset, str]
        if isinstance(self.avatar_color, Unset):
            avatar_color = UNSET
        elif isinstance(self.avatar_color, UserAvatarColor):
            avatar_color = self.avatar_color.value
        else:
            avatar_color = self.avatar_color

        is_admin = self.is_admin

        notify = self.notify

        quota_size_in_bytes: Union[None, Unset, int]
        if isinstance(self.quota_size_in_bytes, Unset):
            quota_size_in_bytes = UNSET
        else:
            quota_size_in_bytes = self.quota_size_in_bytes

        should_change_password = self.should_change_password

        storage_label: Union[None, Unset, str]
        if isinstance(self.storage_label, Unset):
            storage_label = UNSET
        else:
            storage_label = self.storage_label

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "email": email,
                "name": name,
                "password": password,
            }
        )
        if avatar_color is not UNSET:
            field_dict["avatarColor"] = avatar_color
        if is_admin is not UNSET:
            field_dict["isAdmin"] = is_admin
        if notify is not UNSET:
            field_dict["notify"] = notify
        if quota_size_in_bytes is not UNSET:
            field_dict["quotaSizeInBytes"] = quota_size_in_bytes
        if should_change_password is not UNSET:
            field_dict["shouldChangePassword"] = should_change_password
        if storage_label is not UNSET:
            field_dict["storageLabel"] = storage_label

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        email = d.pop("email")

        name = d.pop("name")

        password = d.pop("password")

        def _parse_avatar_color(data: object) -> Union[None, Unset, UserAvatarColor]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                avatar_color_type_1 = UserAvatarColor(data)

                return avatar_color_type_1
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, UserAvatarColor], data)

        avatar_color = _parse_avatar_color(d.pop("avatarColor", UNSET))

        is_admin = d.pop("isAdmin", UNSET)

        notify = d.pop("notify", UNSET)

        def _parse_quota_size_in_bytes(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        quota_size_in_bytes = _parse_quota_size_in_bytes(
            d.pop("quotaSizeInBytes", UNSET)
        )

        should_change_password = d.pop("shouldChangePassword", UNSET)

        def _parse_storage_label(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        storage_label = _parse_storage_label(d.pop("storageLabel", UNSET))

        user_admin_create_dto = cls(
            email=email,
            name=name,
            password=password,
            avatar_color=avatar_color,
            is_admin=is_admin,
            notify=notify,
            quota_size_in_bytes=quota_size_in_bytes,
            should_change_password=should_change_password,
            storage_label=storage_label,
        )

        user_admin_create_dto.additional_properties = d
        return user_admin_create_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="LibraryStatsResponseDto")


@_attrs_define
class LibraryStatsResponseDto:
    """
    Attributes:
        photos (int):  Default: 0.
        total (int):  Default: 0.
        usage (int):  Default: 0.
        videos (int):  Default: 0.
    """

    photos: int = 0
    total: int = 0
    usage: int = 0
    videos: int = 0
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        photos = self.photos

        total = self.total

        usage = self.usage

        videos = self.videos

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "photos": photos,
                "total": total,
                "usage": usage,
                "videos": videos,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        photos = d.pop("photos")

        total = d.pop("total")

        usage = d.pop("usage")

        videos = d.pop("videos")

        library_stats_response_dto = cls(
            photos=photos,
            total=total,
            usage=usage,
            videos=videos,
        )

        library_stats_response_dto.additional_properties = d
        return library_stats_response_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from collections.abc import Mapping
from typing import (
    TYPE_CHECKING,
    Any,
    TypeVar,
    Union,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.notification_level import NotificationLevel
from ..models.notification_type import NotificationType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.notification_dto_data import NotificationDtoData


T = TypeVar("T", bound="NotificationDto")


@_attrs_define
class NotificationDto:
    """
    Attributes:
        created_at (datetime.datetime):
        id (str):
        level (NotificationLevel):
        title (str):
        type_ (NotificationType):
        data (Union[Unset, NotificationDtoData]):
        description (Union[Unset, str]):
        read_at (Union[Unset, datetime.datetime]):
    """

    created_at: datetime.datetime
    id: str
    level: NotificationLevel
    title: str
    type_: NotificationType
    data: Union[Unset, "NotificationDtoData"] = UNSET
    description: Union[Unset, str] = UNSET
    read_at: Union[Unset, datetime.datetime] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        created_at = self.created_at.isoformat()

        id = self.id

        level = self.level.value

        title = self.title

        type_ = self.type_.value

        data: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.data, Unset):
            data = self.data.to_dict()

        description = self.description

        read_at: Union[Unset, str] = UNSET
        if not isinstance(self.read_at, Unset):
            read_at = self.read_at.isoformat()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "createdAt": created_at,
                "id": id,
                "level": level,
                "title": title,
                "type": type_,
            }
        )
        if data is not UNSET:
            field_dict["data"] = data
        if description is not UNSET:
            field_dict["description"] = description
        if read_at is not UNSET:
            field_dict["readAt"] = read_at

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.notification_dto_data import NotificationDtoData

        d = dict(src_dict)
        created_at = isoparse(d.pop("createdAt"))

        id = d.pop("id")

        level = NotificationLevel(d.pop("level"))

        title = d.pop("title")

        type_ = NotificationType(d.pop("type"))

        _data = d.pop("data", UNSET)
        data: Union[Unset, NotificationDtoData]
        if isinstance(_data, Unset):
            data = UNSET
        else:
            data = NotificationDtoData.from_dict(_data)

        description = d.pop("description", UNSET)

        _read_at = d.pop("readAt", UNSET)
        read_at: Union[Unset, datetime.datetime]
        if isinstance(_read_at, Unset):
            read_at = UNSET
        else:
            read_at = isoparse(_read_at)

        notification_dto = cls(
            created_at=created_at,
            id=id,
            level=level,
            title=title,
            type_=type_,
            data=data,
            description=description,
            read_at=read_at,
        )

        notification_dto.additional_properties = d
        return notification_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="FacialRecognitionConfig")


@_attrs_define
class FacialRecognitionConfig:
    """
    Attributes:
        enabled (bool):
        max_distance (float):
        min_faces (int):
        min_score (float):
        model_name (str):
    """

    enabled: bool
    max_distance: float
    min_faces: int
    min_score: float
    model_name: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        enabled = self.enabled

        max_distance = self.max_distance

        min_faces = self.min_faces

        min_score = self.min_score

        model_name = self.model_name

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "enabled": enabled,
                "maxDistance": max_distance,
                "minFaces": min_faces,
                "minScore": min_score,
                "modelName": model_name,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        enabled = d.pop("enabled")

        max_distance = d.pop("maxDistance")

        min_faces = d.pop("minFaces")

        min_score = d.pop("minScore")

        model_name = d.pop("modelName")

        facial_recognition_config = cls(
            enabled=enabled,
            max_distance=max_distance,
            min_faces=min_faces,
            min_score=min_score,
            model_name=model_name,
        )

        facial_recognition_config.additional_properties = d
        return facial_recognition_config

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import (
    TYPE_CHECKING,
    Any,
    TypeVar,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.album_user_add_dto import AlbumUserAddDto


T = TypeVar("T", bound="AddUsersDto")


@_attrs_define
class AddUsersDto:
    """
    Attributes:
        album_users (list['AlbumUserAddDto']):
    """

    album_users: list["AlbumUserAddDto"]
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        album_users = []
        for album_users_item_data in self.album_users:
            album_users_item = album_users_item_data.to_dict()
            album_users.append(album_users_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "albumUsers": album_users,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.album_user_add_dto import AlbumUserAddDto

        d = dict(src_dict)
        album_users = []
        _album_users = d.pop("albumUsers")
        for album_users_item_data in _album_users:
            album_users_item = AlbumUserAddDto.from_dict(album_users_item_data)

            album_users.append(album_users_item)

        add_users_dto = cls(
            album_users=album_users,
        )

        add_users_dto.additional_properties = d
        return add_users_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from collections.abc import Mapping
from typing import (
    Any,
    TypeVar,
    Union,
    cast,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="ExifResponseDto")


@_attrs_define
class ExifResponseDto:
    """
    Attributes:
        city (Union[None, Unset, str]):
        country (Union[None, Unset, str]):
        date_time_original (Union[None, Unset, datetime.datetime]):
        description (Union[None, Unset, str]):
        exif_image_height (Union[None, Unset, float]):
        exif_image_width (Union[None, Unset, float]):
        exposure_time (Union[None, Unset, str]):
        f_number (Union[None, Unset, float]):
        file_size_in_byte (Union[None, Unset, int]):
        focal_length (Union[None, Unset, float]):
        iso (Union[None, Unset, float]):
        latitude (Union[None, Unset, float]):
        lens_model (Union[None, Unset, str]):
        longitude (Union[None, Unset, float]):
        make (Union[None, Unset, str]):
        model (Union[None, Unset, str]):
        modify_date (Union[None, Unset, datetime.datetime]):
        orientation (Union[None, Unset, str]):
        projection_type (Union[None, Unset, str]):
        rating (Union[None, Unset, float]):
        state (Union[None, Unset, str]):
        time_zone (Union[None, Unset, str]):
    """

    city: Union[None, Unset, str] = UNSET
    country: Union[None, Unset, str] = UNSET
    date_time_original: Union[None, Unset, datetime.datetime] = UNSET
    description: Union[None, Unset, str] = UNSET
    exif_image_height: Union[None, Unset, float] = UNSET
    exif_image_width: Union[None, Unset, float] = UNSET
    exposure_time: Union[None, Unset, str] = UNSET
    f_number: Union[None, Unset, float] = UNSET
    file_size_in_byte: Union[None, Unset, int] = UNSET
    focal_length: Union[None, Unset, float] = UNSET
    iso: Union[None, Unset, float] = UNSET
    latitude: Union[None, Unset, float] = UNSET
    lens_model: Union[None, Unset, str] = UNSET
    longitude: Union[None, Unset, float] = UNSET
    make: Union[None, Unset, str] = UNSET
    model: Union[None, Unset, str] = UNSET
    modify_date: Union[None, Unset, datetime.datetime] = UNSET
    orientation: Union[None, Unset, str] = UNSET
    projection_type: Union[None, Unset, str] = UNSET
    rating: Union[None, Unset, float] = UNSET
    state: Union[None, Unset, str] = UNSET
    time_zone: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        city: Union[None, Unset, str]
        if isinstance(self.city, Unset):
            city = UNSET
        else:
            city = self.city

        country: Union[None, Unset, str]
        if isinstance(self.country, Unset):
            country = UNSET
        else:
            country = self.country

        date_time_original: Union[None, Unset, str]
        if isinstance(self.date_time_original, Unset):
            date_time_original = UNSET
        elif isinstance(self.date_time_original, datetime.datetime):
            date_time_original = self.date_time_original.isoformat()
        else:
            date_time_original = self.date_time_original

        description: Union[None, Unset, str]
        if isinstance(self.description, Unset):
            description = UNSET
        else:
            description = self.description

        exif_image_height: Union[None, Unset, float]
        if isinstance(self.exif_image_height, Unset):
            exif_image_height = UNSET
        else:
            exif_image_height = self.exif_image_height

        exif_image_width: Union[None, Unset, float]
        if isinstance(self.exif_image_width, Unset):
            exif_image_width = UNSET
        else:
            exif_image_width = self.exif_image_width

        exposure_time: Union[None, Unset, str]
        if isinstance(self.exposure_time, Unset):
            exposure_time = UNSET
        else:
            exposure_time = self.exposure_time

        f_number: Union[None, Unset, float]
        if isinstance(self.f_number, Unset):
            f_number = UNSET
        else:
            f_number = self.f_number

        file_size_in_byte: Union[None, Unset, int]
        if isinstance(self.file_size_in_byte, Unset):
            file_size_in_byte = UNSET
        else:
            file_size_in_byte = self.file_size_in_byte

        focal_length: Union[None, Unset, float]
        if isinstance(self.focal_length, Unset):
            focal_length = UNSET
        else:
            focal_length = self.focal_length

        iso: Union[None, Unset, float]
        if isinstance(self.iso, Unset):
            iso = UNSET
        else:
            iso = self.iso

        latitude: Union[None, Unset, float]
        if isinstance(self.latitude, Unset):
            latitude = UNSET
        else:
            latitude = self.latitude

        lens_model: Union[None, Unset, str]
        if isinstance(self.lens_model, Unset):
            lens_model = UNSET
        else:
            lens_model = self.lens_model

        longitude: Union[None, Unset, float]
        if isinstance(self.longitude, Unset):
            longitude = UNSET
        else:
            longitude = self.longitude

        make: Union[None, Unset, str]
        if isinstance(self.make, Unset):
            make = UNSET
        else:
            make = self.make

        model: Union[None, Unset, str]
        if isinstance(self.model, Unset):
            model = UNSET
        else:
            model = self.model

        modify_date: Union[None, Unset, str]
        if isinstance(self.modify_date, Unset):
            modify_date = UNSET
        elif isinstance(self.modify_date, datetime.datetime):
            modify_date = self.modify_date.isoformat()
        else:
            modify_date = self.modify_date

        orientation: Union[None, Unset, str]
        if isinstance(self.orientation, Unset):
            orientation = UNSET
        else:
            orientation = self.orientation

        projection_type: Union[None, Unset, str]
        if isinstance(self.projection_type, Unset):
            projection_type = UNSET
        else:
            projection_type = self.projection_type

        rating: Union[None, Unset, float]
        if isinstance(self.rating, Unset):
            rating = UNSET
        else:
            rating = self.rating

        state: Union[None, Unset, str]
        if isinstance(self.state, Unset):
            state = UNSET
        else:
            state = self.state

        time_zone: Union[None, Unset, str]
        if isinstance(self.time_zone, Unset):
            time_zone = UNSET
        else:
            time_zone = self.time_zone

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if city is not UNSET:
            field_dict["city"] = city
        if country is not UNSET:
            field_dict["country"] = country
        if date_time_original is not UNSET:
            field_dict["dateTimeOriginal"] = date_time_original
        if description is not UNSET:
            field_dict["description"] = description
        if exif_image_height is not UNSET:
            field_dict["exifImageHeight"] = exif_image_height
        if exif_image_width is not UNSET:
            field_dict["exifImageWidth"] = exif_image_width
        if exposure_time is not UNSET:
            field_dict["exposureTime"] = exposure_time
        if f_number is not UNSET:
            field_dict["fNumber"] = f_number
        if file_size_in_byte is not UNSET:
            field_dict["fileSizeInByte"] = file_size_in_byte
        if focal_length is not UNSET:
            field_dict["focalLength"] = focal_length
        if iso is not UNSET:
            field_dict["iso"] = iso
        if latitude is not UNSET:
            field_dict["latitude"] = latitude
        if lens_model is not UNSET:
            field_dict["lensModel"] = lens_model
        if longitude is not UNSET:
            field_dict["longitude"] = longitude
        if make is not UNSET:
            field_dict["make"] = make
        if model is not UNSET:
            field_dict["model"] = model
        if modify_date is not UNSET:
            field_dict["modifyDate"] = modify_date
        if orientation is not UNSET:
            field_dict["orientation"] = orientation
        if projection_type is not UNSET:
            field_dict["projectionType"] = projection_type
        if rating is not UNSET:
            field_dict["rating"] = rating
        if state is not UNSET:
            field_dict["state"] = state
        if time_zone is not UNSET:
            field_dict["timeZone"] = time_zone

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)

        def _parse_city(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        city = _parse_city(d.pop("city", UNSET))

        def _parse_country(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        country = _parse_country(d.pop("country", UNSET))

        def _parse_date_time_original(
            data: object,
        ) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                date_time_original_type_0 = isoparse(data)

                return date_time_original_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        date_time_original = _parse_date_time_original(d.pop("dateTimeOriginal", UNSET))

        def _parse_description(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        description = _parse_description(d.pop("description", UNSET))

        def _parse_exif_image_height(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        exif_image_height = _parse_exif_image_height(d.pop("exifImageHeight", UNSET))

        def _parse_exif_image_width(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        exif_image_width = _parse_exif_image_width(d.pop("exifImageWidth", UNSET))

        def _parse_exposure_time(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        exposure_time = _parse_exposure_time(d.pop("exposureTime", UNSET))

        def _parse_f_number(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        f_number = _parse_f_number(d.pop("fNumber", UNSET))

        def _parse_file_size_in_byte(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        file_size_in_byte = _parse_file_size_in_byte(d.pop("fileSizeInByte", UNSET))

        def _parse_focal_length(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        focal_length = _parse_focal_length(d.pop("focalLength", UNSET))

        def _parse_iso(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        iso = _parse_iso(d.pop("iso", UNSET))

        def _parse_latitude(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        latitude = _parse_latitude(d.pop("latitude", UNSET))

        def _parse_lens_model(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        lens_model = _parse_lens_model(d.pop("lensModel", UNSET))

        def _parse_longitude(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        longitude = _parse_longitude(d.pop("longitude", UNSET))

        def _parse_make(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        make = _parse_make(d.pop("make", UNSET))

        def _parse_model(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        model = _parse_model(d.pop("model", UNSET))

        def _parse_modify_date(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                modify_date_type_0 = isoparse(data)

                return modify_date_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        modify_date = _parse_modify_date(d.pop("modifyDate", UNSET))

        def _parse_orientation(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        orientation = _parse_orientation(d.pop("orientation", UNSET))

        def _parse_projection_type(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        projection_type = _parse_projection_type(d.pop("projectionType", UNSET))

        def _parse_rating(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        rating = _parse_rating(d.pop("rating", UNSET))

        def _parse_state(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        state = _parse_state(d.pop("state", UNSET))

        def _parse_time_zone(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        time_zone = _parse_time_zone(d.pop("timeZone", UNSET))

        exif_response_dto = cls(
            city=city,
            country=country,
            date_time_original=date_time_original,
            description=description,
            exif_image_height=exif_image_height,
            exif_image_width=exif_image_width,
            exposure_time=exposure_time,
            f_number=f_number,
            file_size_in_byte=file_size_in_byte,
            focal_length=focal_length,
            iso=iso,
            latitude=latitude,
            lens_model=lens_model,
            longitude=longitude,
            make=make,
            model=model,
            modify_date=modify_date,
            orientation=orientation,
            projection_type=projection_type,
            rating=rating,
            state=state,
            time_zone=time_zone,
        )

        exif_response_dto.additional_properties = d
        return exif_response_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from io import BytesIO
from typing import Any, Optional, Union
from uuid import UUID

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.asset_media_size import AssetMediaSize
from ...types import UNSET, File, Response, Unset


def _get_kwargs(
    id: UUID,
    *,
    key: Union[Unset, str] = UNSET,
    size: Union[Unset, AssetMediaSize] = UNSET,
    slug: Union[Unset, str] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["key"] = key

    json_size: Union[Unset, str] = UNSET
    if not isinstance(size, Unset):
        json_size = size.value

    params["size"] = json_size

    params["slug"] = slug

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/assets/{id}/thumbnail".format(
            id=id,
        ),
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[File]:
    if response.status_code == 200:
        response_200 = File(payload=BytesIO(response.content))

        return response_200

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[File]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    id: UUID,
    *,
    client: AuthenticatedClient,
    key: Union[Unset, str] = UNSET,
    size: Union[Unset, AssetMediaSize] = UNSET,
    slug: Union[Unset, str] = UNSET,
) -> Response[File]:
    """This endpoint requires the `asset.view` permission.

    Args:
        id (UUID):
        key (Union[Unset, str]):
        size (Union[Unset, AssetMediaSize]):
        slug (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[File]
    """

    kwargs = _get_kwargs(
        id=id,
        key=key,
        size=size,
        slug=slug,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    id: UUID,
    *,
    client: AuthenticatedClient,
    key: Union[Unset, str] = UNSET,
    size: Union[Unset, AssetMediaSize] = UNSET,
    slug: Union[Unset, str] = UNSET,
) -> Optional[File]:
    """This endpoint requires the `asset.view` permission.

    Args:
        id (UUID):
        key (Union[Unset, str]):
        size (Union[Unset, AssetMediaSize]):
        slug (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        File
    """

    return sync_detailed(
        id=id,
        client=client,
        key=key,
        size=size,
        slug=slug,
    ).parsed


async def asyncio_detailed(
    id: UUID,
    *,
    client: AuthenticatedClient,
    key: Union[Unset, str] = UNSET,
    size: Union[Unset, AssetMediaSize] = UNSET,
    slug: Union[Unset, str] = UNSET,
) -> Response[File]:
    """This endpoint requires the `asset.view` permission.

    Args:
        id (UUID):
        key (Union[Unset, str]):
        size (Union[Unset, AssetMediaSize]):
        slug (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[File]
    """

    kwargs = _get_kwargs(
        id=id,
        key=key,
        size=size,
        slug=slug,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    id: UUID,
    *,
    client: AuthenticatedClient,
    key: Union[Unset, str] = UNSET,
    size: Union[Unset, AssetMediaSize] = UNSET,
    slug: Union[Unset, str] = UNSET,
) -> Optional[File]:
    """This endpoint requires the `asset.view` permission.

    Args:
        id (UUID):
        key (Union[Unset, str]):
        size (Union[Unset, AssetMediaSize]):
        slug (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        File
    """

    return (
        await asyncio_detailed(
            id=id,
            client=client,
            key=key,
            size=size,
            slug=slug,
        )
    ).parsed



from enum import Enum


class AssetVisibility(str, Enum):
    ARCHIVE = "archive"
    HIDDEN = "hidden"
    LOCKED = "locked"
    TIMELINE = "timeline"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import (
    Any,
    TypeVar,
    Union,
    cast,
)
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="NotificationUpdateAllDto")


@_attrs_define
class NotificationUpdateAllDto:
    """
    Attributes:
        ids (list[UUID]):
        read_at (Union[None, Unset, datetime.datetime]):
    """

    ids: list[UUID]
    read_at: Union[None, Unset, datetime.datetime] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        ids = []
        for ids_item_data in self.ids:
            ids_item = str(ids_item_data)
            ids.append(ids_item)

        read_at: Union[None, Unset, str]
        if isinstance(self.read_at, Unset):
            read_at = UNSET
        elif isinstance(self.read_at, datetime.datetime):
            read_at = self.read_at.isoformat()
        else:
            read_at = self.read_at

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "ids": ids,
            }
        )
        if read_at is not UNSET:
            field_dict["readAt"] = read_at

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        ids = []
        _ids = d.pop("ids")
        for ids_item_data in _ids:
            ids_item = UUID(ids_item_data)

            ids.append(ids_item)

        def _parse_read_at(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                read_at_type_0 = isoparse(data)

                return read_at_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        read_at = _parse_read_at(d.pop("readAt", UNSET))

        notification_update_all_dto = cls(
            ids=ids,
            read_at=read_at,
        )

        notification_update_all_dto.additional_properties = d
        return notification_update_all_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class NotificationType(str, Enum):
    BACKUPFAILED = "BackupFailed"
    CUSTOM = "Custom"
    JOBFAILED = "JobFailed"
    SYSTEMMESSAGE = "SystemMessage"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import (
    TYPE_CHECKING,
    Any,
    TypeVar,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.albums_response import AlbumsResponse
    from ..models.cast_response import CastResponse
    from ..models.download_response import DownloadResponse
    from ..models.email_notifications_response import EmailNotificationsResponse
    from ..models.folders_response import FoldersResponse
    from ..models.memories_response import MemoriesResponse
    from ..models.people_response import PeopleResponse
    from ..models.purchase_response import PurchaseResponse
    from ..models.ratings_response import RatingsResponse
    from ..models.shared_links_response import SharedLinksResponse
    from ..models.tags_response import TagsResponse


T = TypeVar("T", bound="UserPreferencesResponseDto")


@_attrs_define
class UserPreferencesResponseDto:
    """
    Attributes:
        albums (AlbumsResponse):
        cast (CastResponse):
        download (DownloadResponse):
        email_notifications (EmailNotificationsResponse):
        folders (FoldersResponse):
        memories (MemoriesResponse):
        people (PeopleResponse):
        purchase (PurchaseResponse):
        ratings (RatingsResponse):
        shared_links (SharedLinksResponse):
        tags (TagsResponse):
    """

    albums: "AlbumsResponse"
    cast: "CastResponse"
    download: "DownloadResponse"
    email_notifications: "EmailNotificationsResponse"
    folders: "FoldersResponse"
    memories: "MemoriesResponse"
    people: "PeopleResponse"
    purchase: "PurchaseResponse"
    ratings: "RatingsResponse"
    shared_links: "SharedLinksResponse"
    tags: "TagsResponse"
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        albums = self.albums.to_dict()

        cast = self.cast.to_dict()

        download = self.download.to_dict()

        email_notifications = self.email_notifications.to_dict()

        folders = self.folders.to_dict()

        memories = self.memories.to_dict()

        people = self.people.to_dict()

        purchase = self.purchase.to_dict()

        ratings = self.ratings.to_dict()

        shared_links = self.shared_links.to_dict()

        tags = self.tags.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "albums": albums,
                "cast": cast,
                "download": download,
                "emailNotifications": email_notifications,
                "folders": folders,
                "memories": memories,
                "people": people,
                "purchase": purchase,
                "ratings": ratings,
                "sharedLinks": shared_links,
                "tags": tags,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.albums_response import AlbumsResponse
        from ..models.cast_response import CastResponse
        from ..models.download_response import DownloadResponse
        from ..models.email_notifications_response import EmailNotificationsResponse
        from ..models.folders_response import FoldersResponse
        from ..models.memories_response import MemoriesResponse
        from ..models.people_response import PeopleResponse
        from ..models.purchase_response import PurchaseResponse
        from ..models.ratings_response import RatingsResponse
        from ..models.shared_links_response import SharedLinksResponse
        from ..models.tags_response import TagsResponse

        d = dict(src_dict)
        albums = AlbumsResponse.from_dict(d.pop("albums"))

        cast = CastResponse.from_dict(d.pop("cast"))

        download = DownloadResponse.from_dict(d.pop("download"))

        email_notifications = EmailNotificationsResponse.from_dict(
            d.pop("emailNotifications")
        )

        folders = FoldersResponse.from_dict(d.pop("folders"))

        memories = MemoriesResponse.from_dict(d.pop("memories"))

        people = PeopleResponse.from_dict(d.pop("people"))

        purchase = PurchaseResponse.from_dict(d.pop("purchase"))

        ratings = RatingsResponse.from_dict(d.pop("ratings"))

        shared_links = SharedLinksResponse.from_dict(d.pop("sharedLinks"))

        tags = TagsResponse.from_dict(d.pop("tags"))

        user_preferences_response_dto = cls(
            albums=albums,
            cast=cast,
            download=download,
            email_notifications=email_notifications,
            folders=folders,
            memories=memories,
            people=people,
            purchase=purchase,
            ratings=ratings,
            shared_links=shared_links,
            tags=tags,
        )

        user_preferences_response_dto.additional_properties = d
        return user_preferences_response_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
